@@ -96,18 +96,21 @@ class ModelInfoBase(object):
             date_format, datetime_format, time_format = get_date_formats()
 
         if f_value:
-            #if isinstance(field, models.DateTimeField):
             if isinstance(f_value, datetime):
                 return dateformat.format(f_value, datetime_format)
 
-            #if isinstance(field, models.TimeField):
             if isinstance(f_value, time):
                 return dateformat.time_format(f_value, time_format)
 
-            #if isinstance(field, models.DateField):
             if isinstance(f_value, date):
                 return dateformat.format(f_value, date_format)
 
+            if isinstance(f_value, decimal.Decimal):
+                return moneyformat(f_value, None, app_settings.THOUSANDS_SEPARATOR)
+
+            if isinstance(f_value, models.Manager):
+                return ', '.join(map(unicode, f_value.all()))
+
             if field and isinstance(field, models.TextField):
                 if self._meta.auto_urlize: f_value = urlize(f_value)
                 if self._meta.auto_linebreaks: f_value = linebreaksbr(f_value)
